#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const argparse_1 = require("argparse");
const _1 = require("../");
function main(args) {
    return __awaiter(this, void 0, void 0, function* () {
        _1.log.level(args.log);
        let workdir;
        if (args.directory.startsWith(path.sep)) {
            workdir = args.directory;
        }
        else {
            workdir = path.join(process.cwd(), args.directory);
        }
        const facenet = new _1.Facenet();
        const lfw = new _1.Lfw(workdir);
        const faceCache = new _1.FaceCache(workdir);
        const alignmentCache = new _1.AlignmentCache(facenet, faceCache, workdir);
        const embeddingCache = new _1.EmbeddingCache(facenet, workdir);
        yield alignmentCache.init();
        yield embeddingCache.init();
        yield faceCache.init();
        yield facenet.init();
        const count = yield embeddingCache.count();
        let ret = 0;
        switch (args.command) {
            case 'setup':
                const imageList = yield lfw.imageList();
                for (const relativePath of imageList) {
                    const file = path.join(lfw.directory, relativePath);
                    const faceList = yield alignmentCache.align(file);
                    yield Promise.all(faceList.map(face => embeddingCache.embedding(face)));
                }
                _1.log.info('EmbeddingCacheManager', 'cache: %s has inited %d entries', args.directory, count);
                break;
            case 'destroy':
                yield embeddingCache.destroy();
                _1.log.info('EmbeddingCacheManager', 'cleaned %d entries', count);
                break;
            default:
                _1.log.error('LfwManager', 'not supported command: %s', args.command);
                ret = 1;
                break;
        }
        yield facenet.quit();
        return ret;
    });
}
function parseArguments() {
    const parser = new argparse_1.ArgumentParser({
        version: _1.VERSION,
        addHelp: true,
        description: 'Embedding Cache Manager',
    });
    parser.addArgument(['directory'], {
        help: 'Dataset Directory',
    });
    parser.addArgument(['command'], {
        help: 'setup, clean',
        defaultValue: 'setup',
    });
    parser.addArgument(['-l', '--log'], {
        help: 'Log Level: verbose, silly',
        defaultValue: 'info',
    });
    return parser.parseArgs();
}
main(parseArguments())
    .then(process.exit)
    .catch(e => {
    console.error(e);
    process.exit(1);
});
//# sourceMappingURL=embedding-cache-manager.js.map